## THIS MAKES FIGURE 2, then FIGURE 1 ##

library(ape)
library(dplyr)
library(plotrix)

### FIGURE 2
## NUMBER READS AND SPECIES PER GENE

parrot = read.csv("pivotTables_100/presenceAbsence_ONEZERO_edit.csv",row.names=1)
transpose = t(parrot)
totals = as.data.frame(transpose[-length(rownames(transpose)),(length(transpose[1,])-5):(length(transpose[1,]))])
totspecies = totals[order(-totals$TotalSpecies),]
totreads = totals[order(-totals$TotalReads),]

SPP = totspecies$TotalSpecies
sppF = SPP/max(SPP)
sppL = log10(SPP)
READ = totspecies$TotalReads
readF = READ/max(READ)
readL = log10(READ)
NAME = rownames(totspecies)
mtgenes = c("LRNA", "SRNA", "DLOOP", "ND4", "ND4L", 
            "ND1", "CO2", "ND3", "ND5", "16S", "12S", 
            "ND6", "CO1", "CO3", "ATP8", "ATP6", "ND2", "CYTB")
MTYES = as.numeric(NAME %in% mtgenes)
MTCOL = ifelse(MTYES==1,"blue","black")
INDEX = c(1:length(rownames(totspecies)))
BLANKS = rep(" ",length(rownames(totspecies)))
LABELS=c(4,10,30,50,100,300,500,1000,1500)
TOPLOT = log10(LABELS)

pdf("perGeneReadsAndSpecies.pdf",
    w=6,h=4.5)
require(graphics)
par(mgp=c(3.5,1,0),mar=c(5,5,0.5,0.5))  
plot(readL,xaxt="n",ylim=c(0.60206,3.176091),yaxt="n",
     ylab="Number per Gene (Log Scale)",xlab="Gene",
     cex=1,lwd=2)
points(sppL,pch=0,col="red",bg="red",ylim=c(0.60206,3.176091),
       cex=1,lwd=2)
Map(function(x,y,z) 
  axis(1,at=x,col.axis=y,labels=z,cex.axis=0.5,las=2),
  INDEX,
  MTCOL,
  NAME
)
axis(2,at=TOPLOT,labels=LABELS,las=2)
legend(1,log10(30),c(" Number of Sequences",""," Number of Species"),col=c("black",rgb(0,0,0,0),"red"),
       pch=c(1,0,0),pt.bg=c("black",rgb(0,0,0,0),"red"),bty="n",cex=1,pt.cex=1,pt.lwd=2)
dev.off()

## FIGURE 1
## GENES PER SPECIES, BY CLADE

geneperclade <- read.csv("genesPerSpecies_Outgroup_pivot.csv")
names(geneperclade)
small = geneperclade

small$AVGGENE = as.numeric(small$AVGGENE)
small$NUMSPP=as.numeric(small$NUMSPP)
small = small[order(-small$AVGGENE),]

plot(small$AVGGENE)
namesmall = small$NAME
persppsmall = small$AVGGENE
plot(small$AVGGENE[small$LEVEL=="1.SUPERFAMILY"])
superfam = small[small$LEVEL=="1.SUPERFAMILY",]
fam = small[small$LEVEL=="2.FAMILY",]
subfam = small[small$LEVEL=="3.SUBFAMILY",]
subfam = subfam[!(subfam$SUBFAMILY==""),]
tribe = small[small$LEVEL=="4.TRIBE",]
tribe = tribe[!(tribe$TRIBE == ""),]
genus = small[small$LEVEL=="5.GENUS",]

## PLOT FIGURE 1 
## GENERA
pdf("genePerSppOutgroup_genus_09august2017.pdf",
    w = 7,h=17)
par(mar=c(5,6,0.5,0.5))
cols = ifelse(genus$FAMILY=="Cacatuidae",colg[6],
              ifelse(genus$FAMILY=="Strigopidae",colg[1],
                     ifelse(genus$FAMILY=="Nestoridae",colg[2],
                            ifelse(genus$FAMILY=="Psittaculidae",colg[3],
                                   ifelse(genus$FAMILY=="Psittrichasidae",colg[5],colg[4])))))
bords = cols
bords[which(bords=="white")] = "lightpink"
names = as.character(genus$NAME)
make.italic <- function(x) {
  as.expression(lapply(x, function(y) bquote(italic(.(y)))))
}
barplot(as.numeric(genus$AVGGENE),col=cols,pch=pchs,bg=cols,
        xlab = "Average Genes per Species",ylab = "",width=genus$NUMSPP,
        names.arg=make.italic(names),cex.names=0.75,las=1,axis.lty=1,space=0.7,
        border=bords,horiz=T,xlim=c(0,22),xpd=F,
        yaxs="i")
box()
legend(10,200,c("Strigopidae","Nestoridae","Psittaculidae","Psittacidae","Psittrichasidae","Cacatuidae"),
       col=colg,bty="n",fill=colg,border=c(colg[1:length(colg)-1],"lightpink"))
dev.off()
