### THIS SCRIPT MAKES FIGURE 3 ###
## Specifically it makes Figure S4, which was then edited to create Figure 3.

library(ape)
library(phytools)
library(phangorn)
library(RColorBrewer)

filename = "RAxML_bipartitions.ALL_SUBSETS_bootstrap.newick"

trees = read.tree(filename)

## collapse each node in each tree if the support is under 50%
collapseNodes = function(mytree) {
badnodes = which(as.numeric(mytree$node.label) < 50) + length(mytree$tip.label)
badnodes_indexes <- c()
for(node in badnodes){
  badnodes_indexes <- c(badnodes_indexes, which(mytree$edge[,2] == node))
}
collapsed = mytree
collapsed$edge.length[badnodes_indexes] = 0
collapsedtree = di2multi(collapsed)
return(collapsedtree)
}
collapsed = lapply(trees,collapseNodes)
trees = collapsed

## root the trees
rooted = trees
for(i in 1:length(trees)) {
  print(i)
  tree = trees[[i]]
  rootnode = which(tree$tip.label=="Acanthisitta_chloris") ## A
  if(length(rootnode) == 0){
    rootnode = which(tree$tip.label=="Falco_mexicanus") ## F
    rooted[[i]] = ladderize(root(tree,outgroup="Falco_mexicanus",resolve.root=TRUE))
  } else {
    rooted[[i]] = ladderize(root(tree,outgroup="Acanthisitta_chloris",resolve.root=TRUE)) ## A
  }
  print(rootnode)
  rooted[[i]] = ladderize(root(tree,outgroup="Acanthisitta_chloris",resolve.root=TRUE)) ## A
  #print(is.binary.tree(rooted[[i]]))
}

## remove outgroup taxa
for(i in 1:length(rooted)){
  rooted[[i]] = drop.tip(rooted[[i]],tip=c("Falco_mexicanus",
                                     "Acanthisitta_chloris",
                                     "Passer_montanus",
                                     "Tyrannus_tyrannus"))
}


## look up whether each node is present on the base tree 

totalBaseNodes = basetree$Nnode+length(basetree$tip.label)
nodeExistsMatrix = as.data.frame(rep(1,totalBaseNodes))
for(j in 2:length(rooted)){
  testTree= rooted[[j]]
  print(paste("TREE:",j))
  totalTestNodes = testTree$Nnode+length(testTree$tip.label)
  for(i in 1:totalTestNodes) {
    print(paste("~~NODE:",i,"OF",totalTestNodes))
    ## for each node on reduced tree:
    #print(paste0("Descendants of node ",i,":"))
    ## get the tip labels associated with the node
    numtips = (Descendants(testTree,i,type="tips"))[[1]]
    tips = testTree$tip.label[numtips]
    #print(tips)

    basenums = which(basetree$tip.label == tips)
    if(length(tips)==1){
      print("###TIP ONLY###")
    } else {
      ## find the MRCA of those tips on the full tree
      print("###FINDING MRCA###")
      basenode = findMRCA(basetree,tips)
      basenums = which(basetree$tip.label == tips)
      print("###ADDING###")
      nodeExistsMatrix[basenode,1] = j
      nodeExistsMatrix[basenums,1] = j
      ## find the number of those tips on the full tree
    }
    ## in the node existence matrix, if the node exists on tree numbr j,
    ## the corersponding nodeExistsMatrix amount should be j

  }
}
## for each tree
names(nodeExistsMatrix) = "ExistTree"
nodeExistsMatrix$ExistTree = as.numeric(nodeExistsMatrix$ExistTree)

## write the matrix of which nodes exist to a csv file
csvstring = "subsetTreeNodes_raxml_7september2017.csv"
write.csv(nodeExistsMatrix,csvstring)
nodeExistsMatrix = read.csv(csvstring)
names(nodeExistsMatrix)=c("node","ExistTree")

## create color scheme for labels
brewer = (brewer.pal(11,"RdYlBu"))
ramp = colorRampPalette(brewer)
cols = (ramp(15))
legendcols = cols
labelcolors = cols[nodeExistsMatrix$ExistTree]

## get numbers for tips and nodes for plotting labels
tipnums = nodeExistsMatrix$ExistTree[1:length(basetree$tip.label)]
nodenums = nodeExistsMatrix$ExistTree[(length(basetree$tip.label)+1):length(nodeExistsMatrix$ExistTree)]
tipcols = labelcolors[1:length(basetree$tip.label)]
nodecols = labelcolors[(length(basetree$tip.label)+1):length(nodeExistsMatrix$ExistTree)]

## create a "dated" tree for plotting purposes
## do not trust dates! this is only for making the tree ultrametric 
datebase = chronos(ladderize(basetree), lambda = 0, model = "correlated")
reduced = datebase
logbase = datebase
logbase$edge.length = (log(datebase$edge.length))

### THIS MAKES FIGURE S4/3 !!! ###
pdf("Figure3_subsetTreeNodes_raxml_7september2017.pdf",
    width=15,height=15,pointsize=10)
{
{
is_tip <- datebase$edge[,2] <= length(datebase$tip.label)
ordered_tips <- datebase$edge[is_tip, 2]
datebase$tip.label[ordered_tips]
plot(datebase,type="fan",label.offset=0.03,cex=0.8,no.margin=T)
nodelabels(pch=21,col="black",bg=nodecols)
tiplabels(node=tipnums,pch=21,col="black",bg=tipcols)
legend.text = 1:15
legendcols_short = legendcols[1:15]
legend(-0.1,0.25,legend=legend.text,pt.bg=legendcols_short,
       pch=21,ncol=3,inset=0.3,bty="n")
}
dev.off()

## This makes Figure S4/3 without tips 
pdf("Figure3_subsetTreeNodes_raxml_notips_7september2017.pdf",
    width=15,height=15,pointsize=10)
{
  {
  is_tip <- datebase$edge[,2] <= length(datebase$tip.label)
  ordered_tips <- datebase$edge[is_tip, 2]
  datebase$tip.label[ordered_tips]
}
  plot(datebase,type="fan",label.offset=0.03,cex=0.8,no.margin=T,show.tip.label=F)
  {
  }
  nodelabels(pch=21,col="black",bg=nodecols,cex=1.5)
  tiplabels(node=tipnums,pch=21,col="black",bg=tipcols,cex=1.5)
  legend.text = 1:15
  legendcols_short = legendcols[1:15]
  legend(-0.1,0.25,legend=legend.text,pt.bg=legendcols_short,
         pch=21,ncol=3,inset=0.3,bty="n",cex=1.5)
  
}
dev.off()


