## This script creates the raw basis for Figure 5.
## However it will require extensive Inkscape work to recolor properly. 

## try http:// if https:// URLs are not supported
#source("https://bioconductor.org/biocLite.R")
#biocLite("ggtree")
library(ape)
library(ggplot2)
library(ggtree)
library(geiger)
library(phytools)
library(ggthemes)
library(viridis)
library(RColorBrewer)

jetzTree = read.nexus("~/Dropbox/Parrot_Emu_Paper/Raw_Data/Jetz_10k_MCC_keep_50.tre")
jetz1=drop.tip(jetzTree,c("Tyrannus_tyrannus","Acanthisitta_chloris","Passer_montanus","Falco_mexicanus"))
jetz=drop.tip(jetz1,c("Eunymphicus_uvaeensis","Psittacara_brevipes","Psittacara_rubritorquis"))

#color branches based on sampling values
sampling=read.csv("~/Dropbox/Parrot_Emu_Paper/Manuscript_Revision/Tables/not for publication/parrotTraits_31march2017_clementsOnly-sampling.csv",row.names=1,header=T)
samp = sampling
Sampling= sampling

twotraits=read.csv("~/Dropbox/Parrot_Emu_Paper/Manuscript_Revision/Tables/not for publication/parrotTraits_31march2017_clementsOnly-iucn_intra.csv",row.names=1,header=T)
subspecies=read.csv("~/Dropbox/Parrot_Emu_Paper/Manuscript_Revision/Tables/not for publication/parrotTraits_31march2017_clementsOnly-subspecies.csv",row.names=1,header=T)

#specify traits as factors
twotraits$IUCN=as.factor(twotraits$IUCN)
twotraits$Intrasp_Sampling=as.factor(twotraits$Intrasp_Sampling)

iucn = as.data.frame(twotraits$IUCN)
rownames(iucn) = rownames(twotraits)
colnames(iucn) = sub("\\.$", "", colnames(twotraits)[1])

intra = as.data.frame(twotraits$Intrasp_Sampling)
rownames(intra) = rownames(twotraits)
colnames(intra) = sub("\\.$", "", colnames(twotraits)[2])

name.check(jetz,twotraits)
name.check(jetz,iucn)
name.check(jetz,intra)
name.check(jetz,subspecies)

#plots iucn status & subspecies numbers on tips
#problem. it plots same color scheme for both traits. it may be easier to combine multiple plots in inkscape
colnames(twotraits) <- sub("\\.$", "", colnames(twotraits))

pdf("~/Dropbox/Parrot_Emu_Paper/Raw_Data/test_9sept2017.pdf",h=7,w=8)
multiplot(pf,pt, ncol=2)
dev.off()

## testing out coloring branches by sampling
samp = sampling
samp$Spp = rownames(samp)
samp$Sampling = as.logical(samp$Phylo_Sampling)
samp$node <- NA
tipnode <- seq_along(jetzTree$tip.label)
names(tipnode) <- jetzTree$tip.label
samp$node <- tipnode[samp$Spp] ## convert the tip label to tip node number
i <- is.na(samp$node)
samp$node[i] = samp$Spp[i] ## fill in internal node number

## now trying to combine evertything into one raw figure
dataframe = read.csv("parrotTraits_31march2017_clementsOnly.csv")
masterReduced = dataframe[,c(1,3,5,7,14)]
colnames(masterReduced) = c("Spp","IUCN","Subspp","Within","Genbank")
rownames(masterReduced) = masterReduced$Spp
masterReduced$Within = as.logical(masterReduced$Within)
masterReduced$Genbank = as.logical(masterReduced$Genbank)
masterReduced$IUCN = as.factor(masterReduced$IUCN)
masterReduced$node = NA

check = name.check(jetz,masterReduced)
check$data_not_tree
dropped = masterReduced[!rownames(masterReduced) %in% check$data_not_tree, ]

tipnode = seq_along(jetzTree$tip.label)
names(tipnode) <- jetzTree$tip.label
dropped$node <- tipnode[dropped$Spp] ## convert the tip label to tip node number
i <- is.na(dropped$node)
dropped$node[i] = dropped$Spp[i] ## fill in internal node number

ppm <- ggtree(jetz, aes(color = Genbank)) %<+% dropped +
  geom_tiplab(size=3) + 
  geom_treescale() + 
  theme(legend.position=c(0.5,0.5))
ppm

droptrait = dropped[,c(2,4)]

drops = as.data.frame(cbind(rownames(dropped),as.numeric(dropped$Subspp)))
colnames(drops) = c("Spp","Subspp")
drops$Subspp = as.numeric(as.character(drops$Subspp))
jdata = as.data.frame(jetz$tip.label)
colnames(jdata) = "Spp"
drops$Subspp[order(match(jdata$Spp,drops$Spp))]
d3 = merge(x=jdata,y=drops,by.x="Spp",by.y="Spp",sort=F)
colnames(d3) = c("id","value")

dropiucn = as.data.frame(as.factor(droptrait$IUCN))
rownames(dropiucn) = rownames(droptrait)
colnames(dropiucn) = c("IUCN")
name.check(jetz,dropiucn)

ppm1 = facet_plot(ppm, 'heatmap', droptrait, geom_tile, aes(x=1, fill=as.numeric(IUCN)))
ppm1 = facet_plot(ppm, panel="dot", data=dropiucn, 
                  geom=geom_point, aes(x=as.numeric(IUCN)), 
                  color='firebrick')
ppm1

ppm1 = facet_plot(ppm,pane="heatmap",data=droptrait,geom=geom_tile, aes(x=0, xend=value, y=y, yend=y), size=0.5, color='steelblue') #+ theme_tree2()
ppm1 = gheatmap(ppm, droptrait, width=0.05, font.size=3, colnames_angle=-45, hjust=0,low="red", high="blue")
ppm3 = facet_plot(ppm1,panel='bar', data=d3, geom=geom_segment, aes(x=0, xend=value, y=y, yend=y), size=0.5, color='steelblue') #+ theme_tree2()

## Print the raw version of Figure 5, which will need to be re-colored. 
pdf("~/Dropbox/Parrot_Emu_Paper/Raw_Data/Fig5_test_9sept2017.pdf",h=8,w=8)
ppm3
dev.off()
