## this file makes Figure S2 the large backbone tree with smaller subtrees 
## it is not just for raxml boots anymore but displayes the PP from exabayes

library(ape)
library(phytools)
library(ggtree)
library(diversitree)
library(geiger)
library(RColorBrewer)


treestring = "RAxML_bipartitions.ALL_SUBSETS_bootstrap.newick"
inputTrees = read.tree(treestring)
inputTree = inputTrees[[1]]

## assign all taxa to groups
## GENUS
{Acanthisitta=c("Acanthisitta_chloris")
  Agapornis=c("Agapornis_canus","Agapornis_fischeri","Agapornis_lilianae","Agapornis_nigrigenis","Agapornis_personatus","Agapornis_pullarius","Agapornis_roseicollis","Agapornis_swindernianus","Agapornis_taranta")
  Alipiopsitta=c("Alipiopsitta_xanthops")
  Alisterus=c("Alisterus_amboinensis","Alisterus_chloropterus","Alisterus_scapularis")
  Amazona=c("Amazona_aestiva","Amazona_agilis","Amazona_albifrons","Amazona_amazonica","Amazona_arausiaca","Amazona_auropalliata","Amazona_autumnalis","Amazona_barbadensis","Amazona_brasiliensis","Amazona_collaria","Amazona_dufresniana","Amazona_farinosa","Amazona_festiva","Amazona_finschi","Amazona_guildingii","Amazona_imperialis","Amazona_kawalli","Amazona_leucocephala","Amazona_ochrocephala","Amazona_oratrix","Amazona_pretrei","Amazona_rhodocorytha","Amazona_tucumana","Amazona_ventralis","Amazona_versicolor","Amazona_vinacea","Amazona_viridigenalis","Amazona_vittata")
  Anodorhynchus=c("Anodorhynchus_hyacinthinus","Anodorhynchus_leari")
  Aprosmictus=c("Aprosmictus_erythropterus","Aprosmictus_jonquillaceus")
  Ara=c("Ara_ambiguus","Ara_ararauna","Ara_chloropterus","Ara_glaucogularis","Ara_macao","Ara_militaris","Ara_rubrogenys","Ara_severus")
  Aratinga=c("Aratinga_auricapillus","Aratinga_jandaya","Aratinga_maculata","Aratinga_nenday","Aratinga_solstitialis","Aratinga_weddellii")
  Barnardius=c("Barnardius_zonarius")
  Bolbopsittacus=c("Bolbopsittacus_lunulatus")
  Bolborhynchus=c("Bolborhynchus_lineola")
  Brotogeris=c("Brotogeris_chiriri","Brotogeris_chrysoptera","Brotogeris_cyanoptera","Brotogeris_jugularis","Brotogeris_pyrrhoptera","Brotogeris_sanctithomae","Brotogeris_tirica","Brotogeris_versicolurus")
  Cacatua=c("Cacatua_alba","Cacatua_ducorpsii","Cacatua_galerita","Cacatua_goffiniana","Cacatua_haematuropygia","Cacatua_moluccensis","Cacatua_ophthalmica","Cacatua_pastinator","Cacatua_sanguinea","Cacatua_sulphurea")
  Callocephalon=c("Callocephalon_fimbriatum")
  Calyptorhynchus=c("Calyptorhynchus_banksii","Calyptorhynchus_baudinii","Calyptorhynchus_funereus","Calyptorhynchus_lathami","Calyptorhynchus_latirostris")
  Chalcopsitta=c("Chalcopsitta_atra","Chalcopsitta_duivenbodei","Chalcopsitta_scintillata")
  Charmosyna=c("Charmosyna_meeki","Charmosyna_multistriata","Charmosyna_papou","Charmosyna_placentis","Charmosyna_pulchella","Charmosyna_rubronotata")
  Conuropsis=c("Conuropsis_carolinensis")
  Coracopsis=c("Coracopsis_nigra","Coracopsis_vasa")
  Cyanoliseus=c("Cyanoliseus_patagonus")
  Cyanopsitta=c("Cyanopsitta_spixii")
  Cyanoramphus=c("Cyanoramphus_auriceps","Cyanoramphus_forbesi","Cyanoramphus_malherbi","Cyanoramphus_novaezelandiae","Cyanoramphus_saisseti","Cyanoramphus_unicolor")
  Cyclopsitta=c("Cyclopsitta_diophthalma")
  Deroptyus=c("Deroptyus_accipitrinus")
  Diopsittaca=c("Diopsittaca_nobilis")
  Eclectus=c("Eclectus_roratus")
  Enicognathus=c("Enicognathus_leptorhynchus")
  Eolophus=c("Eolophus_roseicapilla")
  Eos=c("Eos_bornea","Eos_cyanogenia","Eos_histrio","Eos_reticulata","Eos_squamata")
  Eunymphicus=c("Eunymphicus_cornutus")
  Eupsittula=c("Eupsittula_aurea","Eupsittula_cactorum","Eupsittula_canicularis","Eupsittula_nana","Eupsittula_pertinax")
  Falco=c("Falco_mexicanus")
  Forpus=c("Forpus_coelestis","Forpus_conspicillatus","Forpus_cyanopygius","Forpus_modestus","Forpus_passerinus","Forpus_xanthops","Forpus_xanthopterygius")
  Geoffroyus=c("Geoffroyus_heteroclitus")
  Glossopsitta=c("Glossopsitta_concinna")
  Graydidascalus=c("Graydidascalus_brachyurus")
  Guaruba=c("Guaruba_guarouba")
  Hapalopsittaca=c("Hapalopsittaca_amazonina","Hapalopsittaca_fuertesi","Hapalopsittaca_melanotis","Hapalopsittaca_pyrrhops")
  Lathamus=c("Lathamus_discolor")
  Leptosittaca=c("Leptosittaca_branickii")
  Lophochroa=c("Lophochroa_leadbeateri")
  Loriculus=c("Loriculus_beryllinus","Loriculus_catamene","Loriculus_galgulus","Loriculus_philippensis","Loriculus_pusillus","Loriculus_stigmatus","Loriculus_vernalis")
  Lorius=c("Lorius_albidinucha","Lorius_chlorocercus","Lorius_domicella","Lorius_garrulus","Lorius_hypoinochrous","Lorius_lory")
  Mascarinus=c("Mascarinus_mascarin")
  Melopsittacus=c("Melopsittacus_undulatus")
  Micropsitta=c("Micropsitta_bruijnii","Micropsitta_finschii","Micropsitta_keiensis","Micropsitta_pusio")
  Myiopsitta=c("Myiopsitta_monachus")
  Nannopsittaca=c("Nannopsittaca_dachilleae","Nannopsittaca_panychlora")
  Neophema=c("Neophema_chrysogaster","Neophema_chrysostoma","Neophema_elegans","Neophema_petrophila","Neophema_pulchella","Neophema_splendida")
  Neopsephotus=c("Neopsephotus_bourkii")
  Neopsittacus=c("Neopsittacus_musschenbroekii","Neopsittacus_pullicauda")
  Nestor=c("Nestor_meridionalis","Nestor_notabilis")
  Northiella=c("Northiella_haematogaster","Northiella_narethae")
  Nymphicus=c("Nymphicus_hollandicus")
  Oreopsittacus=c("Oreopsittacus_arfaki")
  Orthopsittaca=c("Orthopsittaca_manilatus")
  Parvipsitta=c("Parvipsitta_porphyrocephala","Parvipsitta_pusilla")
  Passer=c("Passer_montanus")
  Pezoporus=c("Pezoporus_occidentalis","Pezoporus_wallicus")
  Phigys=c("Phigys_solitarius")
  Pionites=c("Pionites_leucogaster","Pionites_melanocephalus")
  Pionopsitta=c("Pionopsitta_pileata","Pionopsitta_pulchra")
  Pionus=c("Pionus_chalcopterus","Pionus_fuscus","Pionus_maximiliani","Pionus_menstruus","Pionus_senilis","Pionus_sordidus","Pionus_tumultuosus")
  Platycercus=c("Platycercus_adscitus","Platycercus_caledonicus","Platycercus_elegans","Platycercus_eximius","Platycercus_icterotis","Platycercus_venustus")
  Poicephalus=c("Poicephalus_cryptoxanthus","Poicephalus_gulielmi","Poicephalus_meyeri","Poicephalus_robustus","Poicephalus_rueppellii","Poicephalus_rufiventris","Poicephalus_senegalus")
  Polytelis=c("Polytelis_alexandrae","Polytelis_anthopeplus")
  Primolius=c("Primolius_auricollis","Primolius_couloni","Primolius_maracana")
  Prioniturus=c("Prioniturus_discurus","Prioniturus_flavicans","Prioniturus_luconensis","Prioniturus_mada","Prioniturus_mindorensis","Prioniturus_montanus","Prioniturus_platenae","Prioniturus_platurus","Prioniturus_verticalis","Prioniturus_waterstradti")
  Probosciger=c("Probosciger_aterrimus")
  Prosopeia=c("Prosopeia_tabuensis")
  Psephotus=c("Psephotus_chrysopterygius","Psephotus_dissimilis","Psephotus_haematonotus","Psephotus_pulcherrimus","Psephotus_varius")
  Pseudeos=c("Pseudeos_cardinalis","Pseudeos_fuscata")
  Psilopsiagon=c("Psilopsiagon_aymara")
  Psittacara=c("Psittacara_chloropterus","Psittacara_erythrogenys","Psittacara_euops","Psittacara_finschi","Psittacara_holochlorus","Psittacara_leucophthalmus","Psittacara_mitratus","Psittacara_wagleri")
  Psittacella=c("Psittacella_brehmii","Psittacella_picta")
  Psittacula=c("Psittacula_alexandri","Psittacula_calthrapae","Psittacula_columboides","Psittacula_cyanocephala","Psittacula_derbiana","Psittacula_eques","Psittacula_eupatria","Psittacula_exsul","Psittacula_finschii","Psittacula_himalayana","Psittacula_krameri","Psittacula_longicauda","Psittacula_roseata","Psittacula_wardi")
  Psittaculirostris=c("Psittaculirostris_desmarestii","Psittaculirostris_edwardsii")
  Psittacus=c("Psittacus_erithacus")
  Psitteuteles=c("Psitteuteles_goldiei","Psitteuteles_iris","Psitteuteles_versicolor")
  Psittinus=c("Psittinus_cyanurus")
  Psittrichas=c("Psittrichas_fulgidus")
  Purpureicephalus=c("Purpureicephalus_spurius")
  Pyrilia=c("Pyrilia_aurantiocephala","Pyrilia_barrabandi","Pyrilia_caica","Pyrilia_haematotis","Pyrilia_pyrilia","Pyrilia_vulturina")
  Pyrrhura=c("Pyrrhura_albipectus","Pyrrhura_amazonum","Pyrrhura_cruentata","Pyrrhura_frontalis","Pyrrhura_griseipectus","Pyrrhura_hoffmanni","Pyrrhura_lepida","Pyrrhura_leucotis","Pyrrhura_melanura","Pyrrhura_molinae","Pyrrhura_orcesi","Pyrrhura_perlata","Pyrrhura_pfrimeri","Pyrrhura_picta","Pyrrhura_rhodocephala","Pyrrhura_roseifrons","Pyrrhura_rupicola")
  Rhynchopsitta=c("Rhynchopsitta_pachyrhyncha","Rhynchopsitta_terrisi")
  Strigops=c("Strigops_habroptila")
  Tanygnathus=c("Tanygnathus_lucionensis","Tanygnathus_megalorynchos","Tanygnathus_sumatranus")
  Thectocercus=c("Thectocercus_acuticaudatus")
  Touit=c("Touit_batavicus","Touit_purpuratus")
  Trichoglossus=c("Trichoglossus_chlorolepidotus","Trichoglossus_euteles","Trichoglossus_flavoviridis","Trichoglossus_haematodus","Trichoglossus_johnstoniae","Trichoglossus_ornatus")
  Triclaria=c("Triclaria_malachitacea")
  Tyrannus=c("Tyrannus_tyrannus")
  Vini=c("Vini_australis","Vini_peruviana")
  genera=list("Acanthisitta"=Acanthisitta,"Agapornis"=Agapornis,"Alipiopsitta"=Alipiopsitta,"Alisterus"=Alisterus,"Amazona"=Amazona,"Anodorhynchus"=Anodorhynchus,"Aprosmictus"=Aprosmictus,"Ara"=Ara,"Aratinga"=Aratinga,"Barnardius"=Barnardius,"Bolbopsittacus"=Bolbopsittacus,"Bolborhynchus"=Bolborhynchus,"Brotogeris"=Brotogeris,"Cacatua"=Cacatua,"Callocephalon"=Callocephalon,"Calyptorhynchus"=Calyptorhynchus,"Chalcopsitta"=Chalcopsitta,"Charmosyna"=Charmosyna,"Conuropsis"=Conuropsis,"Coracopsis"=Coracopsis,"Cyanoliseus"=Cyanoliseus,"Cyanopsitta"=Cyanopsitta,"Cyanoramphus"=Cyanoramphus,"Cyclopsitta"=Cyclopsitta,"Deroptyus"=Deroptyus,"Diopsittaca"=Diopsittaca,"Eclectus"=Eclectus,"Enicognathus"=Enicognathus,"Eolophus"=Eolophus,"Eos"=Eos,"Eunymphicus"=Eunymphicus,"Eupsittula"=Eupsittula,"Falco"=Falco,"Forpus"=Forpus,"Geoffroyus"=Geoffroyus,"Glossopsitta"=Glossopsitta,"Graydidascalus"=Graydidascalus,"Guaruba"=Guaruba,"Hapalopsittaca"=Hapalopsittaca,"Lathamus"=Lathamus,"Leptosittaca"=Leptosittaca,"Lophochroa"=Lophochroa,"Loriculus"=Loriculus,"Lorius"=Lorius,"Mascarinus"=Mascarinus,"Melopsittacus"=Melopsittacus,"Micropsitta"=Micropsitta,"Myiopsitta"=Myiopsitta,"Nannopsittaca"=Nannopsittaca,"Neophema"=Neophema,"Neopsephotus"=Neopsephotus,"Neopsittacus"=Neopsittacus,"Nestor"=Nestor,"Northiella"=Northiella,"Nymphicus"=Nymphicus,"Oreopsittacus"=Oreopsittacus,"Orthopsittaca"=Orthopsittaca,"Parvipsitta"=Parvipsitta,"Passer"=Passer,"Pezoporus"=Pezoporus,"Phigys"=Phigys,"Pionites"=Pionites,"Pionopsitta"=Pionopsitta,"Pionus"=Pionus,"Platycercus"=Platycercus,"Poicephalus"=Poicephalus,"Polytelis"=Polytelis,"Primolius"=Primolius,"Prioniturus"=Prioniturus,"Probosciger"=Probosciger,"Prosopeia"=Prosopeia,"Psephotus"=Psephotus,"Pseudeos"=Pseudeos,"Psilopsiagon"=Psilopsiagon,"Psittacara"=Psittacara,"Psittacella"=Psittacella,"Psittacula"=Psittacula,"Psittaculirostris"=Psittaculirostris,"Psittacus"=Psittacus,"Psitteuteles"=Psitteuteles,"Psittinus"=Psittinus,"Psittrichas"=Psittrichas,"Purpureicephalus"=Purpureicephalus,"Pyrilia"=Pyrilia,"Pyrrhura"=Pyrrhura,"Rhynchopsitta"=Rhynchopsitta,"Strigops"=Strigops,"Tanygnathus"=Tanygnathus,"Thectocercus"=Thectocercus,"Touit"=Touit,"Trichoglossus"=Trichoglossus,"Triclaria"=Triclaria,"Tyrannus"=Tyrannus,"Vini"=Vini)
}

## TRIBE
{Amoropsittacini=c(Bolborhynchus,Nannopsittaca,Psilopsiagon,Touit)
  Androglossini=c(Alipiopsitta,Amazona,Brotogeris,Graydidascalus,Hapalopsittaca,Myiopsitta,Pionopsitta,Pionus,Pyrilia,Triclaria)
  Androglossini_A=c(Alipiopsitta,Amazona,Graydidascalus,Hapalopsittaca,Pionopsitta,Pionus,Pyrilia,Triclaria)
  Androglossini_B=c(Brotogeris,Myiopsitta)
  Arini=c(Anodorhynchus,Ara,Aratinga,Conuropsis,Cyanoliseus,Cyanopsitta,Deroptyus,Diopsittaca,Enicognathus,Eupsittula,Guaruba,Leptosittaca,Orthopsittaca,Pionites,Primolius,Psittacara,Pyrrhura,Rhynchopsitta,Thectocercus)
  Cacatuini=c(Cacatua,Callocephalon,Eolophus,Lophochroa)
  Cyclopsittini=c(Cyclopsitta,Psittaculirostris)
  Forpini=c(Forpus)
  Loriini=c(Chalcopsitta,Charmosyna,Eos,Glossopsitta,Lorius,Neopsittacus,Oreopsittacus,Parvipsitta,Phigys,Pseudeos,Psitteuteles,Trichoglossus,Vini)
  Melopsittacini=c(Melopsittacus)
  Microglossini=c(Probosciger)
  Micropsittini=c(Micropsitta)
  Pezoporini=c(Neophema,Neopsephotus,Pezoporus)
  Platycercini=c(Barnardius,Cyanoramphus,Eunymphicus,Lathamus,Northiella,Platycercus,Prosopeia,Psephotus,Purpureicephalus)
  Polytelini=c(Alisterus,Aprosmictus,Polytelis)
  Psittaculini=c(Eclectus,Geoffroyus,Mascarinus,Prioniturus,Psittacula,Psittinus,Tanygnathus)
  OUTGROUP=c(Acanthisitta,Falco,Passer,Tyrannus)
  tribes=list("Amoropsittacini"=Amoropsittacini,"Androglossini_A"=Androglossini_A,"Androglossini_B"=Androglossini_B,"Arini"=Arini,"Cacatuini"=Cacatuini,"Cyclopsittini"=Cyclopsittini,"Forpini"=Forpini,"Loriini"=Loriini,"Melopsittacini"=Melopsittacini,"Microglossini"=Microglossini,"Micropsittini"=Micropsittini,"Pezoporini"=Pezoporini,"Platycercini"=Platycercini,"Polytelini"=Polytelini,"Psittaculini"=Psittaculini,"OUTGROUP"=OUTGROUP)
}

## SUBFAM
{Agapornithinae=c(Agapornis,Bolbopsittacus,Loriculus)
  Arinae=c(Amoropsittacini,Androglossini,Arini,Forpini)
  Cacatuinae=c(Cacatuini,Microglossini)
  Calyptorhynchinae=c(Calyptorhynchus)
  Coracopseinae=c(Coracopsis)
  Loriinae=c(Cyclopsittini,Loriini,Melopsittacini)
  Nymphicinae=c(Nymphicus)
  Platycercinae=c(Pezoporini,Platycercini)
  Platycercinae_Pezoporini=c(Pezoporini)
  Platycercinae_Platyercini=c(Platycercini)
  Psittacellinae=c(Psittacella)
  Psittacinae=c(Poicephalus,Psittacus)
  Psittaculinae=c(Micropsittini,Polytelini,Psittaculini)
  Psittrichasinae=c(Psittrichas)
  subfams=list("Agapornithinae"=Agapornithinae,"Arinae"=Arinae,"Cacatuinae"=Cacatuinae,"Calyptorhynchinae"=Calyptorhynchinae,"Coracopseinae"=Coracopseinae,"Loriinae"=Loriinae,"Nymphicinae"=Nymphicinae,"Platycercinae_Pezoporini"=Platycercinae_Pezoporini,"Platycercinae_Platyercini"=Platycercinae_Platyercini,"Psittacellinae"=Psittacellinae,"Psittacinae"=Psittacinae,"Psittaculinae"=Psittaculinae,"Psittrichasinae"=Psittrichasinae,"OUTGROUP"=OUTGROUP)
}

## FAM
{Cacatuidae=c(Cacatuinae,Calyptorhynchinae,Nymphicinae)
  Nestoridae=c(Nestor)
  Psittacidae=c(Arinae,Psittacinae)
  Psittaculidae=c(Agapornithinae,Loriinae,Platycercinae,Psittacellinae,Psittaculinae)
  Psittrichasidae=c(Coracopseinae,Psittrichasinae)
  Strigopidae=c(Strigops)
  fams=list("Cacatuidae"=Cacatuidae,"Nestoridae"=Nestoridae,"Psittacidae"=Psittacidae,"Psittaculidae"=Psittaculidae,"Psittrichasidae"=Psittrichasidae,"Strigopidae"=Strigopidae,"OUTGROUP"=OUTGROUP)
}

## SUPERFAM
{Cacatuoidea=c(Cacatuidae)
  Psittacoidea=c(Psittacidae,Psittaculidae,Psittrichasidae)
  Strigopoidea=c(Nestoridae,Strigopidae)
  superfams=list("Cacatuoidea"=Cacatuoidea,"Psittacoidea"=Psittacoidea,"Strigopoidea"=Strigopoidea,"OUTGROUP"=OUTGROUP)
}

Passeriformes =c(Acanthisitta,Passer,Tyrannus)

## root the tree, change label text if needed so that 100% supported nodes are blank
root = root(inputTree,outgroup=OUTGROUP,resolve.root=T)
root$node.label = as.numeric(root$node.label)
root$node.label[1] = 100 
root$node.label[which(is.na(root$node.label))] = 100
rootblank = root
rootblank$node.label[rootblank$node.label==100] = "" 
rootblank$node.label[1] = ""
rootedTree = root

## collapse the tree so that nodes with under 50% support are polytomies
collapsed = root
badnodes = which(as.numeric(collapsed$node.label) < 50) + length(collapsed$tip.label) 
badnodes_indexes <- c()
for(node in badnodes){
  badnodes_indexes <- c(badnodes_indexes, which(collapsed$edge[,2] == node))
}
collapsed$edge.length[badnodes_indexes] = 0
collapsed = di2multi(collapsed)
collapsed$node.label = as.numeric(collapsed$node.label)

## create color palatte for node colors
brewer = rev(brewer.pal(9,"YlOrRd"))
ramp = colorRampPalette(brewer)
cols = ramp(50)
names(cols) = seq(51,100)
plot(1:50,col=cols,pch=21,bg=cols)
labelcolors = cols[collapsed$node.label-50]

## FIGURE S1
## print the full large bootstrap tree, with low-support nodes collapsed
pdf("raxml_bootstrapCollapsedTree_8september2017.pdf",
    width=15,height=40,pointsize=10)
plot.phylo(collapsed,no.margin=T,type="phylogram",align.tip.label = T,
           show.node.label = F,bg=labelcolors,cex=0.75)
nodelabels(collapsed$node.label,frame="n",cex=0.5,bg=labelcolors
           ,adj=c(1.2,-0.75))
nodelabels(pch=21,bg=labelcolors,cex=0.5)
add.scale.bar()
dev.off()

## FIGURE S2
## create multiple-panel PDF of subtrees 

lad = ladderize(midpoint.root(collapsed))

## create function to extract one species from each larger clade
makeSmallerTree = function(test,fams){
  onePer_fams = c()
  for(fam in fams){
    onePer_fams = c(onePer_fams,fam[1])
  }
  toDrop_fams = test$tip.label[!(test$tip.label %in% onePer_fams)]
  
  testd = (drop.tip(test, toDrop_fams))
  names(fams[testd$tip.label %in% fams])
  labels = c()
  for(tip in testd$tip.label){
    #print(tip)
    for(fam in names(fams)){
      #print(c("!!!!!",fam))
      column = which(names(fams)==fam)
      #print(column)
      #fams[[column]]
      if(tip %in% fams[[column]]){
        #print(c(tip,fam))
        labels = c(labels,fam)
      }
    }
  }
  testd$tip.label = labels
  return(testd)
}

## modify zoom function from APE package to draw custom bootstrap values 
zoom_custom <- function(phy, focus, subtree = FALSE, col = rainbow,
                        ...) {
  par(mfrow=c(1,1))
  if (!is.list(focus)) {
    focus <- list(focus)}
  n <- length(focus)
  for (i in 1:n) 
    if (is.character(focus[[i]])) {
      focus[[i]] <- which(phy$tip.label %in% focus[[i]]) # fix by Yan Wong 
    }
  if (is.function(col)) {
    col <- if (deparse(substitute(col)) == "grey") grey(1:n/n) else col(n)
  }
  ext <- vector("list", n)
  tips = c()
  for (i in 1:n) {
    ext[[i]] <- drop.tip(phy, phy$tip.label[-focus[[i]]],
                         subtree = subtree, rooted = TRUE) 
    tips = c(tips,length(ext[[i]]$tip.label)+2)
    }
    
  #nc <- round(sqrt(n)) + 1
  #nr <- ceiling(sqrt(n))
  nr = n
  #nr = 1
  nc = 2
  M <- matrix(0, nr, nc)
  #print(M)
  x <- c(rep(1, nr), 2:(n + 1))
  M[1:length(x)] <- x
  #print(M);print(x);print(nc);print(nr);print(tips)
  layout(M, c(1, rep(3/(nc - 1), nc - 1))
         #,heights=log(tips))
         #,heights=(tips))
  )
  #layout.show()
  phy$tip.label <- rep("", length(phy$tip.label))
  colo <- rep("black", dim(phy$edge)[1])
  for (i in 1:n) {
    colo[which.edge(phy, focus[[i]])] <- col[i] }
  plot.phylo(phy, edge.color = colo, ...)
  for (i in 1:n) {
    ext[[i]]$node.nums = ext[[i]]$node.label
    ext[[i]]$node.asts = ext[[i]]$node.label
    
    ext[[i]]$node.nums[ext[[i]]$node.label=="Root"] = ""
    ext[[i]]$node.nums[ext[[i]]$node.label==100] = ""
    
    ext[[i]]$node.asts[ext[[i]]$node.label=="Root"] = "*"
    ext[[i]]$node.asts[ext[[i]]$node.label==100] = "*"
    ext[[i]]$node.asts[ext[[i]]$node.asts!="*"] = ""
      
    ext[[i]]$root.edge = 0.01
    #print(blank$node.label)
    plot.phylo(ext[[i]], edge.color = col[i],
               align.tip.label=T,
               #,tip.color=rgb(0,0,0,0),
               ...)
    #tiplabels(ext[[i]]$tip.label,cex=tipcex,frame="n",
    #          col="black")
    #nodelabels(ext[[i]]$node.asts,frame="n",adj=-0.25) 
    }
    nodelabels(ext[[i]]$node.nums,frame="n",adj=-0.25,
               cex=0.5)
    add.scale.bar()
}


## make list of taxa, in order, for sub-tree printing
{
  orders=list("Strigopidae"=Strigopidae,"Nestoridae"=Nestoridae,
                "Nymphicinae"=Nymphicinae,"Calyptorhynchinae"=Calyptorhynchinae,"Microglossini"=Microglossini,"Cacatuini"=Cacatuini,
             "Psittrichasinae"=Psittrichasinae,"Coracopseinae"=Coracopseinae,
             "Psittaculini"=Psittaculini,"Micropsittini"=Micropsittini,"Polytelini"=Polytelini,
             "Psittacellinae"=Psittacellinae,"Pezoporini"=Pezoporini,
             "Platycercini"=Platycercini,"Agapornithinae"=Agapornithinae,
             "Melopsittacini"=Melopsittacini,"Cyclopsittacini"=Cyclopsittini,"Loriini"=Loriini,
             "Psittacinae"=Psittacinae,
             "Amoropsittacini"=Amoropsittacini,"Androglossini_B"=Androglossini_B,
             "Androglossini_A"=Androglossini_A,"Forpini"=Forpini,
             "Arini"=Arini)} 
             
## extract one species from each of the ordered taxa, replace species name with taxon name
testd = makeSmallerTree(lad,orders)

## create custom labels 
testd$node.nums = testd$node.label
testd$node.asts = testd$node.label
testd$node.nums[testd$node.label=="Root"] = ""
testd$node.nums[testd$node.label==100] = ""
testd$node.asts[testd$node.label=="Root"] = "*"
testd$node.asts[testd$node.label==100] = "*"
testd$node.asts[testd$node.asts!="*"] = ""

## make list of colors associated with each taxon for plotting purposes
{ordercol = c("brown","red",
             "magenta","cyan",
             "lightsteelblue","turquoise",
             "mediumpurple","seagreen",
             "lightseagreen","deepskyblue",
             "cadetblue","blue",
             "cornflowerblue","blueviolet",
             "dodgerblue")
}

## make list of cex values for each other 
## if cex is set too small, clades become too thin to discern topology
## if cex is set too big, clade names will not display properly

ordercex = c(0.9,0.65,## Strig, Caca
        0.9,0.6,          ## Psittrich, Psittacul
        0.9,0.7,    ## Pez, Psittacel
        0.6,0.7,    ## Platycer, Aga
        0.6,0.65,    ## Lor, Psittacin
        0.7,0.75,    ## Amor, AndroB
        0.65,0.75,    ## AndroA, Forp
        0.6)         ## Ari

## print Figure S2
pdfstring = paste("/Users/kprovost/Dropbox/Parrots/ParrotPipelineRedo/August_Exabayes/supermatrix_100_copy/raxml_zoomTree_NOTLOG_",
                  "ALL","_8september2017.pdf",sep="")
pdf(pdfstring,width=10,height=10,pointsize=24)
for(i in 1:length(order)){
  tax = order[[i]]
  nam = names(order)[i]
  col = ordercol[i]
  cex = ordercex[i]
  #if(nam %in% c("Psittaculinae","Platycercini","Loriinae",
  #              "Androglossini_A","Arini")){ cex = 0.6 } 
  #else if (nam %in% c("Strigopoidea","Psittrichasidae")) { cex = 0.9 } ## 9 works ## 8 no
  #else if (nam %in% c("Psittaculidae")) { cex = 0.95 }
  #else { cex = 0.75 }
  zoom_custom(lad,focus=tax,col=col,subtree=F,no.margin=T,show.node.label=F,
              label.offset=0,edge.width=2,cex=cex,root.edge=T)
}
dev.off()
