## This script makes Supplementary Figure 3

library(ape)
library(phytools)
library(phangorn)
library(RColorBrewer)

filename = "RAxML_bipartitions.ALL_SUBSETS_bootstrap.newick"

trees = read.tree(filename)
trees = trees[[1]] ## extract the first tree, the main tree 

collapseNodes = function(mytree) {
  badnodes = which(as.numeric(mytree$node.label) < 50) + length(mytree$tip.label)
  badnodes_indexes <- c()
  for(node in badnodes){
    badnodes_indexes <- c(badnodes_indexes, which(mytree$edge[,2] == node))
  }
  collapsed = mytree
  collapsed$edge.length[badnodes_indexes] = 0
  collapsedtree = di2multi(collapsed)
  return(collapsedtree)
}

## collapse nodes with fewer than 50% bootstrap support 
collapsed = collapseNodes(trees)
trees = collapsed

## root the trees with the outgroup, then delete the outgroup from the trees 
rooted = trees
tree = trees 
  rootnode = which(tree$tip.label=="Acanthisitta_chloris") ## A
  if(length(rootnode) == 0){
    rootnode = which(tree$tip.label=="Falco_mexicanus") ## F
    rooted = ladderize(root(tree,outgroup="Falco_mexicanus",resolve.root=TRUE))
  } else {
    rooted = ladderize(root(tree,outgroup="Acanthisitta_chloris",resolve.root=TRUE)) ## A
  }
  print(rootnode)
  rooted = ladderize(root(tree,outgroup="Acanthisitta_chloris",resolve.root=TRUE)) ## A
  rooted = drop.tip(rooted,tip=c("Falco_mexicanus",
                                           "Acanthisitta_chloris",
                                           "Passer_montanus",
                                           "Tyrannus_tyrannus"))

## create an ultrametric phylogeny by dating the tree 
## note: dates are meaningless without further interrogation
basetree = rooted
rooteven = ladderize(basetree)
rooteven$edge.length = rep(1,length(rooteven$edge.length))
datebase = chronos(rooteven, lambda = 0, model = "correlated") ## creates a round but ultrametric phylogeny
basetree = datebase

## import CSV of missing data 
missingcsv = "missingBasePairs_0.csv"
missing = read.csv(missingcsv)
totbases = 29907 ## adjust as needed 
missing$notmissing_percent = missing$NOTMISSING_29907/totbases
missing$MISSING_29907 = totbases-missing$NOTMISSING_29907
missing$missing_percent = missing$MISSING_29907/totbases
missing$missing_category = missing$missing_percent %/% 0.1 
missing$missing_percent_2 = round(missing$missing_percent,2)*100
noout = missing[which(!(missing$SPECIES %in% c("Falco_mexicanus",
                              "Acanthisitta_chloris",
                              "Passer_montanus",
                              "Tyrannus_tyrannus"))),]
sorted = noout[match(basetree$tip.label, noout$SPECIES),]

brewer = (brewer.pal(7,"RdYlBu"))
ramp = colorRampPalette(brewer)
cols = rev(brewer)
legendcols = cols
labelcolors = cols[sorted$missing_category-2]

pdf("missingdata_raxml_complete_8sept2017.pdf",
width=15,height=15,pointsize=10)
plot(basetree,show.tip.label = T,type="fan",
     label.offset=0.03,cex=0.8,no.margin=T)
tiplabels(text=sorted$missing_percent_2,bg=labelcolors,frame="c",cex=0.3)
legend.text = c("30-39","40-49","50-59","60-69",
                "70-79","80-89","90-100")
legend(-0.1,0.25,legend=legend.text,pt.bg=legendcols,
       pch=21,ncol=4,inset=0.3,bty="n",cex=1.5,title="Percent Bases Missing")
dev.off()

